package com.nisum.example.producer;

import org.apache.kafka.clients.producer.*;
import org.apache.kafka.common.serialization.StringSerializer;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Properties;

public class ProducerDemoWithCallBack {
    public static void main(String[] args) {

        Logger logger= LoggerFactory.getLogger(ProducerDemoWithCallBack.class);

        String bootstrapServer="127.0.0.1:9092";

        //create producer properties
        Properties properties=new Properties();
        properties.setProperty(ProducerConfig.BOOTSTRAP_SERVERS_CONFIG,bootstrapServer);
        properties.setProperty(ProducerConfig.KEY_SERIALIZER_CLASS_CONFIG, StringSerializer.class.getName());
        properties.setProperty(ProducerConfig.VALUE_SERIALIZER_CLASS_CONFIG,StringSerializer.class.getName());

        //create producer
        KafkaProducer<String,String> kafkaProducer=new KafkaProducer<String, String>(properties);

        //create a producer record
        ProducerRecord<String,String> producerRecord=new ProducerRecord<>("first_topic","Hello World");

        //send data asynchronous
        kafkaProducer.send(producerRecord, new Callback() {
            @Override
            public void onCompletion(RecordMetadata metadata, Exception exception) {
                //executes every time record is successfully send or exception is thrown
                if(exception==null){
                    //record send sucessfully
                    logger.info("Received new Metadata. \n",
                            "Topic:"+metadata.topic()+"\n"
                                    +"Partition:"+metadata.partition()+"\n"
                    +"Offset:"+metadata.offset()+"\n"
                    +"Timestamp:"+metadata.timestamp());
                }
                else {
                    logger.error("Error while producing",exception);
                }
            }
        });

        //flush data
        kafkaProducer.flush();

        //close the producer
        kafkaProducer.close();
    }
}
